==> cutefish-filemanager-0.4-2.src.tar.gz: filemanager-0.4/translations/ta_IN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ta">
<context>
    <name>CreateFolderDialog</name>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="28"/>
        <source>New folder name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="55"/>
        <source>New folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="70"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="76"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DateHelper</name>
    <message>
        <location filename="../helper/datehelper.cpp" line="15"/>
        <source>Now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="17"/>
        <source>1 minute ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="19"/>
        <source>%1 minutes ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="23"/>
        <source>1 hour ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="25"/>
        <source>%1 hours ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="29"/>
        <source>1 day ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="31"/>
        <source>%1 days ago</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DesktopView</name>
    <message>
        <location filename="../desktop/desktopview.cpp" line="44"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EmptyTrashDialog</name>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="30"/>
        <source>File Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="60"/>
        <source>Do you want to permanently delete all files from the Trash?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="69"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="75"/>
        <source>Empty Trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FolderModel</name>
    <message>
        <location filename="../model/foldermodel.cpp" line="166"/>
        <source>%1 item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="166"/>
        <source>%1 items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="830"/>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1042"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1045"/>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1048"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1051"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1054"/>
        <source>New Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1057"/>
        <source>Move To Trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1060"/>
        <source>Empty Trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1063"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1066"/>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1069"/>
        <source>Open in Terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1072"/>
        <source>Set as Wallpaper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1075"/>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1078"/>
        <source>Change background</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FolderPage</name>
    <message>
        <location filename="../qml/FolderPage.qml" line="54"/>
        <source>Empty folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="85"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="90"/>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="146"/>
        <source>%1 item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="147"/>
        <source>%1 items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="153"/>
        <source>%1 selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="164"/>
        <source>Empty Trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OptionsMenu</name>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="45"/>
        <source>Icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="79"/>
        <source>List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="115"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="149"/>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="183"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlacesModel</name>
    <message>
        <location filename="../model/placesmodel.cpp" line="39"/>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="46"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="53"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="60"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="67"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="74"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="81"/>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="86"/>
        <source>Trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="28"/>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="103"/>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="116"/>
        <source>Location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="127"/>
        <source>Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="135"/>
        <source>Calculating...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="140"/>
        <source>Created:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="153"/>
        <source>Modified:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="166"/>
        <source>Accessed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="188"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="197"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs/propertiesdialog.cpp" line="209"/>
        <source>%1 files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="35"/>
        <source>File Manager</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> cutefish-filemanager-0.8-2.src.tar.gz: filemanager-0.8/translations/ta_IN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ta">
<context>
    <name>CreateFolderDialog</name>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="28"/>
        <source>New folder name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="55"/>
        <source>New folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="79"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="85"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DateHelper</name>
    <message>
        <location filename="../helper/datehelper.cpp" line="15"/>
        <source>Now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="17"/>
        <source>1 minute ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="19"/>
        <source>%1 minutes ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="23"/>
        <source>1 hour ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="25"/>
        <source>%1 hours ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="29"/>
        <source>1 day ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="31"/>
        <source>%1 days ago</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeleteDialog</name>
    <message>
        <location filename="../qml/Dialogs/DeleteDialog.qml" line="47"/>
        <source>Do you want to delete it permanently?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/DeleteDialog.qml" line="56"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/DeleteDialog.qml" line="62"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DesktopView</name>
    <message>
        <location filename="../desktop/desktopview.cpp" line="44"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EmptyTrashDialog</name>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="30"/>
        <source>File Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="60"/>
        <source>Do you want to permanently delete all files from the Trash?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="69"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="75"/>
        <source>Empty Trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FilePropertiesDialog</name>
    <message>
        <location filename="../dialogs/filepropertiesdialog.cpp" line="179"/>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs/filepropertiesdialog.cpp" line="227"/>
        <source>%1 files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FolderModel</name>
    <message>
        <location filename="../model/foldermodel.cpp" line="184"/>
        <source>%1 item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="184"/>
        <source>%1 items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="249"/>
        <source>The file or folder %1 does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="981"/>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1088"/>
        <source>File Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1281"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1284"/>
        <source>Open with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1287"/>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1290"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1293"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1296"/>
        <source>New Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1299"/>
        <source>Move To Trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1302"/>
        <source>Empty Trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1305"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1308"/>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1311"/>
        <source>Open in Terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1314"/>
        <source>Set as Wallpaper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1317"/>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1320"/>
        <source>Change background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1323"/>
        <source>Restore</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FolderPage</name>
    <message>
        <location filename="../qml/FolderPage.qml" line="134"/>
        <source>Empty folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="174"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="60"/>
        <location filename="../qml/FolderPage.qml" line="179"/>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="50"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="53"/>
        <source>New Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="67"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="73"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="76"/>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="83"/>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="88"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="93"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="99"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="102"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="241"/>
        <source>%1 item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="242"/>
        <source>%1 items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="248"/>
        <source>%1 selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="259"/>
        <source>Empty Trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenWithDialog</name>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="78"/>
        <source>No applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="142"/>
        <source>Set as default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="151"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="160"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs/openwithdialog.cpp" line="32"/>
        <source>Open With</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OptionsMenu</name>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="47"/>
        <source>Icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="85"/>
        <source>List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="127"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="165"/>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="189"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="227"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlacesModel</name>
    <message>
        <location filename="../model/placesmodel.cpp" line="39"/>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="47"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="55"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="63"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="71"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="79"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="87"/>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="93"/>
        <source>Trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="117"/>
        <location filename="../model/placesmodel.cpp" line="265"/>
        <source>Drives</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="94"/>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="107"/>
        <source>Location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="118"/>
        <source>Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="125"/>
        <source>Calculating...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="129"/>
        <source>Created:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="142"/>
        <source>Modified:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="155"/>
        <source>Accessed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="177"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="183"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="35"/>
        <source>File Manager</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
